//----------------------------------------------------------------------------
// TAviDialog v. 1.0 - (C) Copyright 1995 by Kent Reisdorph, 75522,1174
//
// July 25, 1995
//
// #include "avidlg.h"
//
// Definition of class TAviDialog, a class to play an AVI video in
// a 3D dialog box with start, stop, rewind buttons and a slider
// control.
//----------------------------------------------------------------------------

#ifndef _AVIDLG_H
#define _AVIDLG_H

#define STRICT
#ifndef __DIR_H
#include <dir.h>
#endif
#ifndef __STDIO_H
#include <stdio.h>
#endif
#ifndef __OWL_APPLICAT_H
#include <owl\applicat.h>
#endif
#ifndef __OWL_DIALOG_H
#include <owl\dialog.h>
#endif
#ifndef __OWL_STATIC_H
#include <owl\static.h>
#endif
#ifndef __OWL_DC_H
#include <owl\dc.h>
#endif
#ifndef __OWL_GDIOBJEC_H
#include <owl\gdiobjec.h>
#endif
#ifndef __OWL_SLIDER_H
#include <owl\slider.h>
#endif
#ifndef __OWL_BUTTON_H
#include <owl\button.h>
#endif
#ifndef __MMSYTEM_H
#include <mmsystem.h>
#endif
#ifndef __DIGITALV_H
#include <digitalv.h>
#endif
#include "avidlg.rh"

// The class definintion for the owner drawn button class
class TODAButton : public TButton {
	public:
		TODAButton(TWindow* parent, int resId, int bm, int bm2, TModule* module = 0) :
			TButton(parent, resId, module) {bmId = bm; bm2Id = bm2;}
		~TODAButton() {}
		void SetupWindow();
		LRESULT BMSetStyle(WPARAM wParam, LPARAM);
		virtual void EvMouseMove(UINT modkeys, TPoint& point) {}
		virtual void ODADrawEntire(DRAWITEMSTRUCT far& drawInfo);
		virtual void ODAFocus(DRAWITEMSTRUCT far& drawInfo) {}
		virtual void ODASelect(DRAWITEMSTRUCT far& drawInfo) {ODADrawEntire(drawInfo);}
		int bmId;
		int bm2Id;

	 DECLARE_RESPONSE_TABLE(TODAButton);
};

// TPlainSlider class. This is a slider class which does nothing
// more that make sure that the ruler doesn't get drawn on the
// slider.
class TPlainSlider : public THSlider {
	public:
		TPlainSlider(TWindow* parent, int id, int x, int y, int w, int h) :
			THSlider(parent, id, x, y, w, h) {};
		void PaintRuler(TDC&) {};
};

// TAviDialog class definition
class TAviDialog : public TDialog {
	public:
		TAviDialog(TWindow* parent, const char far* filename,
		const char far* title = 0, BOOL autoplay = TRUE,
		BOOL autoclose = TRUE, TModule* module = 0);
		~TAviDialog();
		void SetFilename(const char far* filename);
	protected:
		void SetupWindow();
		LRESULT MciNotify(WPARAM, LPARAM);
		void EvTimer(UINT);
		void EvHScroll(UINT, UINT, HWND);
		void EvPaint();
	private:
		void	CmPlay();
		void	CmStop();
		void	CmRewind();
		DWORD OpenFile();
		DWORD CloseFile();
		DWORD GetAviLength();
		DWORD GetAviPosition();
		RECT	GetSourceRect();
		DWORD GetAviStatus(DWORD item);
		void	PaintAvi();
		void	SetAviPosition(DWORD to);
		DWORD SetDestinationRect(int x, int y, int w, int h, DWORD flags = MCI_WAIT);
		DWORD SetPlaybackWindow(HWND hwnd);
		void	SizeDialog();
		RECT	Where(DWORD flags = MCI_WAIT);

		const char far* fileName;
		BOOL autoPlay;
		BOOL autoClose;
		BOOL deviceOpen;
		BOOL ctl3dEnabled;
		UINT deviceID;
		DWORD fileLength;
		TStatic* VideoWindow;
		TStatic* Frame;
		TStatic* SliderStatic;
		TPlainSlider* Slider;
		HWND playbackWindow;

	DECLARE_RESPONSE_TABLE(TAviDialog);
};

// GetAviPosition. Calls GetAviStatus with MCI_STATUS_POSTION flag
// to get the current position of the avi video.
inline DWORD TAviDialog::GetAviPosition()  {
	return GetAviStatus(MCI_STATUS_POSITION);
}

// GetAviLength. Calls GetAviStatus with MCI_STATUS_LENGHT flag to
// determine the total length of the video clip so that we can set
// the slider range (in SizeDialog()).
inline DWORD TAviDialog::GetAviLength() {
	return GetAviStatus(MCI_STATUS_LENGTH);
}

// GetSourceRect. Gets the size of the video rectangle.
inline RECT TAviDialog::GetSourceRect() {
	return Where(MCI_WAIT | MCI_DGV_WHERE_SOURCE);
}

#endif
